# coding: utf-8

"""
    Clio API Documentation

    # Developer Support and Feedback * Clio takes the availability and stability of our API seriously; please report any **degradations** or **breakages** to Clio's API Support team at [api@clio.com](mailto:api@clio.com). * For business and partnership inquiries, contact our API Partnerships team at [api.partnerships@clio.com](mailto:api.partnerships@clio.com). * For best practices and tips from the Clio development community, join the conversation in the [Clio Developer Slack Channel](https://join.slack.com/t/clio-public/shared_invite/zt-1bd5nfbiv-WloZR3ZjepoUTv28SI1ezw).  A community-driven [Clio Developers Stack Overflow Group](https://stackoverflow.com/questions/tagged/clio-api) also exists where you can connect and ask questions from other Clio API users. # Getting Started > **Note:** The API is available in four distinct data regions: Australia (au.app.clio.com), Canada (ca.app.clio.com), EU (eu.app.clio.com) and US (app.clio.com). > > Likewise, the developer portal is available at region-specific links for the [Australia](https://au.developers.clio.com), [Canada](https://ca.developers.clio.com), [EU](https://eu.developers.clio.com), and [US](https://developers.clio.com) regions. > > This document assumes the US region is being used (app.clio.com). If you're building in one of the other regions, you should adapt the links and examples as necessary.  To start building on the Clio API, you’ll need a Clio account – you can review our [Developer Handbook](https://docs.developers.clio.com/) and follow the steps to sign up for an account.  Once you have an account, you can [create a developer application](https://docs.developers.clio.com/api-docs/applications) from the [Developer Portal](https://developers.clio.com) and start building! # Authorization with OAuth 2.0 See our [Authorization documentation →](https://docs.developers.clio.com/api-docs/authorization) # Permissions See our [Permissions documentation →](https://docs.developers.clio.com/api-docs/permissions) # Fields See our [Fields documentation →](https://docs.developers.clio.com/api-docs/fields) # Rate Limiting See our [Rate Limits documentation →](https://docs.developers.clio.com/api-docs/rate-limits) # Paging See our [Pagination documentation →](https://docs.developers.clio.com/api-docs/paging) # ETags See our [ETags documentation →](https://docs.developers.clio.com/api-docs/etags) # Minor Versions API v4 supports multiple minor versions. Versions are of the form '4.X.Y'. To request a specific version, you can use an `X-API-VERSION` header in your request, with the header value set to the API version you're requesting. If this header is omitted, it will be treated as a request for the default API version. If the header is present but invalid, it will return a `410 Gone` response. If the header is present and valid, but it is no longer supported, it will return a `410 Gone` response.  An `X-API-VERSION` will be included in all successful responses, with the value being set to the API version used.  You can find our [API Versioning Policy and Guidelines](https://docs.developers.clio.com/api-docs/api-versioning-policy) in our documentation hub.  The [API Changelog](https://docs.developers.clio.com/api-docs/api-changelog) explains each version's changes in further detail. - 4.0.4    Update `quantity` field to return values in seconds rather than hours for Activities  - 4.0.5    * Remove `matter_balances` field from Bills   * Standardize status/state enum values   * Add a Document association to completed DocumentAutomations   * Add rate visibility handling for Activity's price and total  - 4.0.6    Remove `document_versions` collection field from Documents  - 4.0.7    Change secure link format  - 4.0.8    * `Activity` hours are redacted in the response based on the activity hours visibility setting for the user   * Add `quantity_redacted` field to activities  - 4.0.9    **This is the default version**    Contacts are filtered and redacted in the response based on the new 'Contacts Visibility' user permission setting.  - 4.0.10    Fixed validation of `type` query parameter when querying Notes   

    The version of the OpenAPI document: v4
    Contact: api@clio.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date, datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, validator

class ActivityBase(BaseModel):
    """
    ActivityBase
    """
    id: Optional[StrictInt] = Field(default=None, description="Unique identifier for the *Activity*")
    etag: Optional[StrictStr] = Field(default=None, description="ETag for the *Activity*")
    type: Optional[StrictStr] = Field(default=None, description="The type of the *Activity*")
    var_date: Optional[date] = Field(default=None, alias="date", description="The date the *Activity* was performed (as a ISO-8601 date)")
    quantity_in_hours: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The number of hours the TimeEntry took.")
    rounded_quantity_in_hours: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The number of hours rounded accordingly to the billing settings. The rounded value is used to calculate the total. ")
    quantity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The field is applicable to TimeEntry, ExpenseEntry, and SoftCostEntry.  **Version <= 4.0.3:** The number of hours the TimeEntry took.  **Latest version:** The number of seconds the TimeEntry took. ")
    rounded_quantity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The field is applicable to time entries only.  **Version <= 4.0.3:** The number of hours rounded accordingly to the billing settings. The rounded value is used to calculate the total.  **Latest version:** The number of seconds rounded accordingly to the billing settings. The rounded value is used to calculate the total. ")
    quantity_redacted: Optional[StrictBool] = Field(default=None, description="Is `true` if any of the following fields are redacted: `quantity`, `rounded_quantity`, `rounded_quantity_in_hours`, `quantity_in_hours`, `total`, `non_billable_total` ")
    price: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The hourly or flat rate of the *Activity*")
    note: Optional[StrictStr] = Field(default=None, description="The details about the *Activity*")
    flat_rate: Optional[StrictBool] = Field(default=None, description="Whether the *Activity* is a flat rate")
    billed: Optional[StrictBool] = Field(default=None, description="Whether the *Activity* has been added to an active bill that is in the state of `awaiting_payment` or `paid`")
    on_bill: Optional[StrictBool] = Field(default=None, description="Whether the *Activity* has been added to an active bill that is in the state of `draft`, `awaiting_approval`, `awaiting_payment` or `paid`")
    total: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The total cost of draft, billable and billed items in the *Activity*")
    contingency_fee: Optional[StrictBool] = Field(default=None, description="Whether or not the *Activity* is a contingency fee")
    created_at: Optional[datetime] = Field(default=None, description="The time the *Activity* was created (as a ISO-8601 timestamp)")
    updated_at: Optional[datetime] = Field(default=None, description="The time the *Activity* was last updated (as a ISO-8601 timestamp)")
    reference: Optional[StrictStr] = Field(default=None, description="A check reference for a HardCostEntry.")
    non_billable: Optional[StrictBool] = Field(default=None, description="Whether the *Activity* is non-billable")
    non_billable_total: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The total cost of non-billable items in the *Activity*")
    no_charge: Optional[StrictBool] = Field(default=None, description="Whether the non-billable *Activity* is shown on the bill.")
    tax_setting: Optional[StrictStr] = Field(default=None, description="The option denoting whether primary tax, secondary tax, or both is applied to an expense entry.")
    __properties = ["id", "etag", "type", "date", "quantity_in_hours", "rounded_quantity_in_hours", "quantity", "rounded_quantity", "quantity_redacted", "price", "note", "flat_rate", "billed", "on_bill", "total", "contingency_fee", "created_at", "updated_at", "reference", "non_billable", "non_billable_total", "no_charge", "tax_setting"]

    @validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('TimeEntry', 'ExpenseEntry', 'HardCostEntry', 'SoftCostEntry'):
            raise ValueError("must be one of enum values ('TimeEntry', 'ExpenseEntry', 'HardCostEntry', 'SoftCostEntry')")
        return value

    @validator('tax_setting')
    def tax_setting_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in ('no_tax', 'tax_1_only', 'tax_2_only', 'tax_1_and_tax_2'):
            raise ValueError("must be one of enum values ('no_tax', 'tax_1_only', 'tax_2_only', 'tax_1_and_tax_2')")
        return value

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ActivityBase:
        """Create an instance of ActivityBase from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ActivityBase:
        """Create an instance of ActivityBase from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ActivityBase.parse_obj(obj)

        _obj = ActivityBase.parse_obj({
            "id": obj.get("id"),
            "etag": obj.get("etag"),
            "type": obj.get("type"),
            "var_date": obj.get("date"),
            "quantity_in_hours": obj.get("quantity_in_hours"),
            "rounded_quantity_in_hours": obj.get("rounded_quantity_in_hours"),
            "quantity": obj.get("quantity"),
            "rounded_quantity": obj.get("rounded_quantity"),
            "quantity_redacted": obj.get("quantity_redacted"),
            "price": obj.get("price"),
            "note": obj.get("note"),
            "flat_rate": obj.get("flat_rate"),
            "billed": obj.get("billed"),
            "on_bill": obj.get("on_bill"),
            "total": obj.get("total"),
            "contingency_fee": obj.get("contingency_fee"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "reference": obj.get("reference"),
            "non_billable": obj.get("non_billable"),
            "non_billable_total": obj.get("non_billable_total"),
            "no_charge": obj.get("no_charge"),
            "tax_setting": obj.get("tax_setting")
        })
        return _obj


