# coding: utf-8

"""
    Clio API Documentation

    # Developer Support and Feedback * Clio takes the availability and stability of our API seriously; please report any **degradations** or **breakages** to Clio's API Support team at [api@clio.com](mailto:api@clio.com). * For business and partnership inquiries, contact our API Partnerships team at [api.partnerships@clio.com](mailto:api.partnerships@clio.com). * For best practices and tips from the Clio development community, join the conversation in the [Clio Developer Slack Channel](https://join.slack.com/t/clio-public/shared_invite/zt-1bd5nfbiv-WloZR3ZjepoUTv28SI1ezw).  A community-driven [Clio Developers Stack Overflow Group](https://stackoverflow.com/questions/tagged/clio-api) also exists where you can connect and ask questions from other Clio API users. # Getting Started > **Note:** The API is available in four distinct data regions: Australia (au.app.clio.com), Canada (ca.app.clio.com), EU (eu.app.clio.com) and US (app.clio.com). > > Likewise, the developer portal is available at region-specific links for the [Australia](https://au.developers.clio.com), [Canada](https://ca.developers.clio.com), [EU](https://eu.developers.clio.com), and [US](https://developers.clio.com) regions. > > This document assumes the US region is being used (app.clio.com). If you're building in one of the other regions, you should adapt the links and examples as necessary.  To start building on the Clio API, you’ll need a Clio account – you can review our [Developer Handbook](https://docs.developers.clio.com/) and follow the steps to sign up for an account.  Once you have an account, you can [create a developer application](https://docs.developers.clio.com/api-docs/applications) from the [Developer Portal](https://developers.clio.com) and start building! # Authorization with OAuth 2.0 See our [Authorization documentation →](https://docs.developers.clio.com/api-docs/authorization) # Permissions See our [Permissions documentation →](https://docs.developers.clio.com/api-docs/permissions) # Fields See our [Fields documentation →](https://docs.developers.clio.com/api-docs/fields) # Rate Limiting See our [Rate Limits documentation →](https://docs.developers.clio.com/api-docs/rate-limits) # Paging See our [Pagination documentation →](https://docs.developers.clio.com/api-docs/paging) # ETags See our [ETags documentation →](https://docs.developers.clio.com/api-docs/etags) # Minor Versions API v4 supports multiple minor versions. Versions are of the form '4.X.Y'. To request a specific version, you can use an `X-API-VERSION` header in your request, with the header value set to the API version you're requesting. If this header is omitted, it will be treated as a request for the default API version. If the header is present but invalid, it will return a `410 Gone` response. If the header is present and valid, but it is no longer supported, it will return a `410 Gone` response.  An `X-API-VERSION` will be included in all successful responses, with the value being set to the API version used.  You can find our [API Versioning Policy and Guidelines](https://docs.developers.clio.com/api-docs/api-versioning-policy) in our documentation hub.  The [API Changelog](https://docs.developers.clio.com/api-docs/api-changelog) explains each version's changes in further detail. - 4.0.4    Update `quantity` field to return values in seconds rather than hours for Activities  - 4.0.5    * Remove `matter_balances` field from Bills   * Standardize status/state enum values   * Add a Document association to completed DocumentAutomations   * Add rate visibility handling for Activity's price and total  - 4.0.6    Remove `document_versions` collection field from Documents  - 4.0.7    Change secure link format  - 4.0.8    * `Activity` hours are redacted in the response based on the activity hours visibility setting for the user   * Add `quantity_redacted` field to activities  - 4.0.9    **This is the default version**    Contacts are filtered and redacted in the response based on the new 'Contacts Visibility' user permission setting.  - 4.0.10    Fixed validation of `type` query parameter when querying Notes   

    The version of the OpenAPI document: v4
    Contact: api@clio.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import List, Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, conlist
from clio-cli.models.group_base import GroupBase
from clio-cli.models.utbms_code_base import UtbmsCodeBase

class ExpenseCategory(BaseModel):
    """
    ExpenseCategory
    """
    id: Optional[StrictInt] = Field(default=None, description="Unique identifier for the *ExpenseCategory*")
    etag: Optional[StrictStr] = Field(default=None, description="ETag for the *ExpenseCategory*")
    name: Optional[StrictStr] = Field(default=None, description="The name of the expense category")
    rate: Optional[StrictInt] = Field(default=None, description="The price charged per unit cost")
    entry_type: Optional[StrictStr] = Field(default=None, description="The type of expense entry the category is associated to. Can be either \"hard_cost\", \"soft_cost\" or \"unassociated\"")
    created_at: Optional[datetime] = Field(default=None, description="The time the *ExpenseCategory* was created (as a ISO-8601 timestamp)")
    updated_at: Optional[datetime] = Field(default=None, description="The time the *ExpenseCategory* was last updated (as a ISO-8601 timestamp)")
    xero_expense_code: Optional[StrictStr] = Field(default=None, description="Custom Xero expense code for an expense category")
    accessible_to_user: Optional[StrictBool] = Field(default=None, description="Determines if expense category is accessible to user")
    tax_setting: Optional[StrictStr] = Field(default=None, description="The type of tax rate applied to the expense category.")
    groups: Optional[conlist(GroupBase)] = Field(default=None, description="Group")
    utbms_code: Optional[UtbmsCodeBase] = None
    __properties = ["id", "etag", "name", "rate", "entry_type", "created_at", "updated_at", "xero_expense_code", "accessible_to_user", "tax_setting", "groups", "utbms_code"]

    class Config:
        """Pydantic configuration"""
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExpenseCategory:
        """Create an instance of ExpenseCategory from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in groups (list)
        _items = []
        if self.groups:
            for _item in self.groups:
                if _item:
                    _items.append(_item.to_dict())
            _dict['groups'] = _items
        # override the default output from pydantic by calling `to_dict()` of utbms_code
        if self.utbms_code:
            _dict['utbms_code'] = self.utbms_code.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExpenseCategory:
        """Create an instance of ExpenseCategory from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExpenseCategory.parse_obj(obj)

        _obj = ExpenseCategory.parse_obj({
            "id": obj.get("id"),
            "etag": obj.get("etag"),
            "name": obj.get("name"),
            "rate": obj.get("rate"),
            "entry_type": obj.get("entry_type"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "xero_expense_code": obj.get("xero_expense_code"),
            "accessible_to_user": obj.get("accessible_to_user"),
            "tax_setting": obj.get("tax_setting"),
            "groups": [GroupBase.from_dict(_item) for _item in obj.get("groups")] if obj.get("groups") is not None else None,
            "utbms_code": UtbmsCodeBase.from_dict(obj.get("utbms_code")) if obj.get("utbms_code") is not None else None
        })
        return _obj


